==> interzone-1.0.19.tar.gz: lib/disk.dart <==
// just use hive for now

import 'dart:convert';
import 'dart:math';
import 'dart:typed_data';

class interzoneDisk {
  //HiveInterface db = Hive;
  final dynamic db;
  int dataPulledDisk = 0;
  int dataPushedDisk = 0;
  //Ipfs _ipfs;
  bool ready = false;
  bool _ghostMode = false;
  dynamic _foCapBox;
  dynamic _kaCapBox;
  dynamic _xxBox;
  dynamic _xxCidToxx;
  dynamic _prefsCapBox;
  dynamic _mutesCapBox;
  dynamic _deletesCapBox;
  dynamic _ipfsCapBox;
  dynamic _appCachesCapBox;
  interzoneDisk(this.db);
  bool _inited = false;
  Future<bool> init(String path, bool ghostMode) async {
    //await db.initFlutter(); //init db elsewhere

    _ghostMode = ghostMode;

    _foCapBox = await db.openBox('focalCapsule' + path);
    _xxBox = await db.openBox('xxCache' + path);
    _xxCidToxx = await db.openBox('xxCacheCids' + path);
    _kaCapBox = await db.openBox('katamari' + path);
    _prefsCapBox = await db.openBox('sitesprefs');
    _mutesCapBox = await db.openBox('prefsmutes' + path);
    _deletesCapBox = await db.openBox('prefsdelete' + path);
    _ipfsCapBox = await db.openBox('ipfsCapsule' + path);
    _appCachesCapBox = await db.openBox('appCaches' + path);

    ready = true;
    return true;
  }

  Future<Uint8List> get readKatamari async {
    Uint8List? u = await _kaCapBox.get('katamari');
    //_ubox.close();

    if (u == null) {
      return Uint8List(0);
    }
    dataPulledDisk += u.lengthInBytes;

    print('[DB] read DONE');
    return u;
  }

  Future<bool> commitKatamari(Uint8List capsule) async {
    //conv into binary
    //if (db == null) return false;
    _kaCapBox.put('katamari', capsule);
    print('[DB] commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<Uint8List?> get readCapsule async {
    Uint8List? u = await _foCapBox.get('capsule');
    //_ubox.close();

    if (u == null) {
      return null;
    }
    dataPulledDisk += u.lengthInBytes;

    print('[DB] read DONE');
    return u;
  }

  Future<bool> commitCapsule(Uint8List capsule) async {
    //conv into binary
    //if (db == null) return false;
    _foCapBox.put('capsule', capsule);
    print('[DB] commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Uint8List Uint64binaryList(List<int> d) {
    if (d.isEmpty) return Uint8List(0);
    int w = 0;
    Uint8List _l = Uint8List(128000);
    var b0 = new ByteData.view(_l.buffer);
    for (var id in d) {
      b0.setInt64(w, id);
      w += 8;
      if (w > _l.lengthInBytes) break;
    }
    return _l.sublist(0, w);
  }

  List<int> ListFromUint64binary(Uint8List data) {
    List<int> _l = [];
    if (data.isEmpty) return _l;
    var b = new ByteData.view(data.buffer);
    var w = 0;
    while (w < data.lengthInBytes) {
      _l.add(b.getInt64(w));
      w += 8;
    }
    return _l;
  }

  Future<bool> commitDeletesPreferences(List<int> l) async {
    //conv into binary
    if (db == null) return false;
    final d = Uint64binaryList(l);
    dataPushedDisk += d.lengthInBytes;

    await _deletesCapBox.put('deletes', d);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<List<int>?> get readDeletesPreferences async {
    Uint8List? u = await _deletesCapBox.get('deletes');
    //_ubox.close();

    if (u == null) {
      return null;
    }
    dataPulledDisk += u.lengthInBytes;

    return ListFromUint64binary(u);
  }

  Future<List<int>> readUint64List(String target) async {
    //conv into binary
    Uint8List? u = await _appCachesCapBox.get(target);
    if (u == null) {
      return [];
    }
    dataPulledDisk += u.lengthInBytes;
    return ListFromUint64binary(u);
  }

  Map<String, dynamic> _clBoxCache = {};
  Future<bool> commitUint64List(List<int> l, String target) async {
    //conv into binary
    if (db == null) return false;
    final d = Uint64binaryList(l);
    dataPushedDisk += d.lengthInBytes;
    await _appCachesCapBox.put(target, d);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<Uint8List> readUint8List(String target) async {
    //conv into binary
    Uint8List? u = await _appCachesCapBox.get(target);
    if (u == null) {
      return Uint8List(0);
    }
    dataPulledDisk += u.lengthInBytes;
    return u;
  }

  Future<bool> deleteUint8List(String target) async {
    //conv into binary
    Uint8List? u = await _appCachesCapBox.delete(target);
    if (u == null) {
      return false;
    }
    return true;
  }

  Future<bool> commitUint8List(Uint8List l, String target) async {
    //conv into binary
    if (db == null) return false;
    dataPushedDisk += l.lengthInBytes;
    await _appCachesCapBox.put(target, l);
    print('[DB] commitUint8List DONE');
    return true;
  }

  Future<bool> commitMutesPreferences(List<String> l) async {
    //conv into binary
    if (db == null) return false;
    String s = '';
    l.forEach((element) {
      s = s + element + ':';
    });
    dataPushedDisk += s.length;
    await _mutesCapBox.put('mutes', s);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<List<String>?> get readMutesPreferences async {
    String? u = await _mutesCapBox.get('mutes');
    //_ubox.close();

    if (u == null) {
      return null;
    }
    dataPulledDisk += u.length;
    print('[DB] read DONE');
    List<String> _l = [];
    var uu = u.split(':');
    _l.add(uu[0]); //sesid
    if (uu.length > 1) {
      _l.add(uu[1]);
    }
    return _l;
  }

  Future<bool> commitIpfsPreferences(String l) async {
    //conv into binary
    if (db == null) return false;
    dataPushedDisk += l.length;
    await _ipfsCapBox.put('ipfsPrefs', l);
    return true;
  }

  Future<String> get readIpfsPreferences async {
    //conv into binary
    if (db == null) return '';
    final p = await _ipfsCapBox.get('ipfsPrefs');
    if (p == null) return '';

    return p;
  }

  /*Future<bool> commitPreferences(
      String dartSesId, String author, String avatar) async {
    //conv into binary
    if (db == null) return false;
    var p = dartSesId + ':' + author + ':' + avatar;
    dataPushedDisk += p.length;
    await _prefsCapBox.put('prifs', p);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }*/
  Future<bool> commitPreferences(String prefs) async {
    dataPushedDisk += prefs.length;
    await _prefsCapBox.put(0, prefs);
    print('[DB] prefs commit DONE');
    return true;
  }

  Future<String> get readPreferences async {
    String? u = await _prefsCapBox.get(0);
    if (u == null) {
      return '';
    }
    dataPulledDisk += u.length;
    return u;
  }

  Future<bool> commitCid(Uint8List data, String cid) async {
    //conv into binary
    dataPushedDisk += data.lengthInBytes;
    _xxBox.put(cid, data);
    print('[DB] commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Uint8List? readCid(String cid) {
    dataPulledDisk += cid.length;
    return _xxBox.get(cid);
  }

  bool dropCid(String cid) {
    return _xxBox.delete(cid);
  }
}

==> interzone-1.0.23.tar.gz: lib/disk.dart <==
// just use hive for now

import 'dart:convert';
import 'dart:math';
import 'dart:typed_data';

class interzoneDisk {
  //HiveInterface db = Hive;
  final dynamic db;
  int dataPulledDisk = 0;
  int dataPushedDisk = 0;
  //Ipfs _ipfs;
  bool ready = false;
  bool _ghostMode = false;
  dynamic _foCapBox;
  dynamic _kaCapBox;
  dynamic _xxBox;
  dynamic _xxCidToxx;
  dynamic _prefsCapBox;
  dynamic _mutesCapBox;
  dynamic _deletesCapBox;
  dynamic _ipfsCapBox;
  dynamic _appCachesCapBox;
  interzoneDisk(this.db);
  bool _inited = false;
  Future<bool> init(String path, bool ghostMode) async {
    //await db.initFlutter(); //init db elsewhere

    _ghostMode = ghostMode;

    _foCapBox = await db.openBox('focalCapsule' + path);
    _xxBox = await db.openBox('xxCache' + path);
    _xxCidToxx = await db.openBox('xxCacheCids' + path);
    _kaCapBox = await db.openBox('katamari' + path);
    _prefsCapBox = await db.openBox('sitesprefs');
    _mutesCapBox = await db.openBox('prefsmutes' + path);
    _deletesCapBox = await db.openBox('prefsdelete' + path);
    _ipfsCapBox = await db.openBox('ipfsCapsule' + path);
    _appCachesCapBox = await db.openBox('appCaches' + path);

    ready = true;
    return true;
  }

  Future<Uint8List> get readKatamari async {
    Uint8List? u = await _kaCapBox.get('katamari');
    //_ubox.close();

    if (u == null) {
      return Uint8List(0);
    }
    dataPulledDisk += u.lengthInBytes;

    print('[DB] read DONE');
    return u;
  }

  Future<bool> commitKatamari(Uint8List capsule) async {
    //conv into binary
    //if (db == null) return false;
    _kaCapBox.put('katamari', capsule);
    print('[DB] commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<Uint8List?> get readCapsule async {
    Uint8List? u = await _foCapBox.get('capsule');
    //_ubox.close();

    if (u == null) {
      return null;
    }
    dataPulledDisk += u.lengthInBytes;

    print('[DB] read DONE');
    return u;
  }

  Future<bool> commitCapsule(Uint8List capsule) async {
    //conv into binary
    //if (db == null) return false;
    _foCapBox.put('capsule', capsule);
    print('[DB] commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Uint8List Uint64binaryList(List<int> d) {
    if (d.isEmpty) return Uint8List(0);
    int w = 0;
    Uint8List _l = Uint8List(128000);
    var b0 = new ByteData.view(_l.buffer);
    for (var id in d) {
      b0.setInt64(w, id);
      w += 8;
      if (w > _l.lengthInBytes) break;
    }
    return _l.sublist(0, w);
  }

  List<int> ListFromUint64binary(Uint8List data) {
    List<int> _l = [];
    if (data.isEmpty) return _l;
    var b = new ByteData.view(data.buffer);
    var w = 0;
    while (w < data.lengthInBytes) {
      _l.add(b.getInt64(w));
      w += 8;
    }
    return _l;
  }

  Future<bool> commitDeletesPreferences(List<int> l) async {
    //conv into binary
    if (db == null) return false;
    final d = Uint64binaryList(l);
    dataPushedDisk += d.lengthInBytes;

    await _deletesCapBox.put('deletes', d);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<List<int>?> get readDeletesPreferences async {
    Uint8List? u = await _deletesCapBox.get('deletes');
    //_ubox.close();

    if (u == null) {
      return null;
    }
    dataPulledDisk += u.lengthInBytes;

    return ListFromUint64binary(u);
  }

  Future<List<int>> readUint64List(String target) async {
    //conv into binary
    Uint8List? u = await _appCachesCapBox.get(target);
    if (u == null) {
      return [];
    }
    dataPulledDisk += u.lengthInBytes;
    return ListFromUint64binary(u);
  }

  Map<String, dynamic> _clBoxCache = {};
  Future<bool> commitUint64List(List<int> l, String target) async {
    //conv into binary
    if (db == null) return false;
    final d = Uint64binaryList(l);
    dataPushedDisk += d.lengthInBytes;
    await _appCachesCapBox.put(target, d);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<Uint8List> readUint8List(String target) async {
    //conv into binary
    Uint8List? u = await _appCachesCapBox.get(target);
    if (u == null) {
      return Uint8List(0);
    }
    dataPulledDisk += u.lengthInBytes;
    return u;
  }

  Future<bool> deleteUint8List(String target) async {
    //conv into binary
    Uint8List? u = await _appCachesCapBox.delete(target);
    if (u == null) {
      return false;
    }
    return true;
  }

  Future<bool> commitUint8List(Uint8List l, String target) async {
    //conv into binary
    if (db == null) return false;
    dataPushedDisk += l.lengthInBytes;
    await _appCachesCapBox.put(target, l);
    print('[DB] commitUint8List DONE');
    return true;
  }

  Future<bool> commitMutesPreferences(List<String> l) async {
    //conv into binary
    if (db == null) return false;
    String s = '';
    l.forEach((element) {
      s = s + element + ':';
    });
    dataPushedDisk += s.length;
    await _mutesCapBox.put('mutes', s);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<List<String>?> get readMutesPreferences async {
    String? u = await _mutesCapBox.get('mutes');
    //_ubox.close();

    if (u == null) {
      return null;
    }
    dataPulledDisk += u.length;
    print('[DB] read DONE');
    List<String> _l = [];
    var uu = u.split(':');
    _l.add(uu[0]); //sesid
    if (uu.length > 1) {
      _l.add(uu[1]);
    }
    return _l;
  }

  Future<bool> commitIpfsPreferences(String l) async {
    //conv into binary
    if (db == null) return false;
    dataPushedDisk += l.length;
    await _ipfsCapBox.put('ipfsPrefs', l);
    return true;
  }

  Future<String> get readIpfsPreferences async {
    //conv into binary
    if (db == null) return '';
    final p = await _ipfsCapBox.get('ipfsPrefs');
    if (p == null) return '';

    return p;
  }

  /*Future<bool> commitPreferences(
      String dartSesId, String author, String avatar) async {
    //conv into binary
    if (db == null) return false;
    var p = dartSesId + ':' + author + ':' + avatar;
    dataPushedDisk += p.length;
    await _prefsCapBox.put('prifs', p);
    print('[DB] prefs commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }*/
  Future<bool> commitPreferences(String prefs) async {
    dataPushedDisk += prefs.length;
    await _prefsCapBox.put(0, prefs);
    print('[DB] prefs commit DONE');
    return true;
  }

  Future<String> get readPreferences async {
    String? u = await _prefsCapBox.get(0);
    if (u == null) {
      return '';
    }
    dataPulledDisk += u.length;
    return u;
  }

  Future<bool> commitCid(Uint8List data, String cid) async {
    //conv into binary
    dataPushedDisk += data.lengthInBytes;
    _xxBox.put(cid, data);
    print('[DB] commit DONE');
    //_ubox.close();
    return true;
    //print(u.binary.sublist(64, 132));
  }

  Future<bool> mapCidToXX(String cid, int xx) async {
    //conv into binary
    _xxCidToxx.put(xx.toString(), cid);
    print('[DB] commit DONE');
    return true;
  }

  Future<String?> readCidForXX(int xx) async {
    return _xxCidToxx.get(xx.toString());
  }

  Uint8List? readCid(String cid) {
    dataPulledDisk += cid.length;
    return _xxBox.get(cid);
  }

  bool dropCid(String cid) {
    final t = _xxBox.delete(cid);
    if (t != null) return true;
    return false;
  }
}
